==> georgesngandeu_hello-0.0.1.tar.gz: georgesngandeu_hello-0.0.1/README.md <==
<!-- PROJECT LOGO -->
<br />
<p align="center">
  <h3 align="center">Simple python package</h3>
  <p align="center">
    <a href="https://github.com/Georges-Ngandeu"><strong>Explore the docs »</strong></a>
    <br />
    <a href="https://github.com/Georges-Ngandeu">View Demo</a>
    ·
    <a href="https://github.com/Georges-Ngandeu">Report Bug</a>
    ·
    <a href="https://github.com/Georges-Ngandeu">Request Feature</a>
  </p>
</p>

<!-- TABLE OF CONTENTS -->
<details open="open">
  <summary><h2 style="display: inline-block">Table of Contents</h2></summary>
  <ol>
    <li><a href="#getting">Getting started</a></li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
    <li><a href="#acknowledgements">Acknowledgements</a></li>
  </ol>
</details>


<!-- GETTING STARTED -->
## Getting Started
A simple python package that prints "Hello wolrd"
<!-- USAGE EXAMPLES -->
## Usage

<!-- LICENSE -->
## License

<!-- CONTACT -->
## Contact

Project Link: [https://github.com/Georges-Ngandeu/AfrikpayNodeSdk](https://github.com/Georges-Ngandeu/AfrikpayNodeSdk)

<!-- ACKNOWLEDGEMENTS -->
## Acknowledgements

* []()
* []()
* []()

<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[contributors-shield]: https://img.shields.io/github/contributors/github_username/repo.svg?style=for-the-badge
[contributors-url]: https://github.com/github_username/repo/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/github_username/repo.svg?style=for-the-badge
[forks-url]: https://github.com/github_username/repo/network/members
[stars-shield]: https://img.shields.io/github/stars/github_username/repo.svg?style=for-the-badge
[stars-url]: https://github.com/github_username/repo/stargazers
[issues-shield]: https://img.shields.io/github/issues/github_username/repo.svg?style=for-the-badge
[issues-url]: https://github.com/github_username/repo/issues
[license-shield]: https://img.shields.io/github/license/github_username/repo.svg?style=for-the-badge
[license-url]: https://github.com/github_username/repo/blob/master/LICENSE.txt
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555
[linkedin-url]: https://linkedin.com/in/github_username

==> georgesngandeu_hello-0.0.2.tar.gz: georgesngandeu_hello-0.0.2/README.md <==
<!-- PROJECT LOGO -->
<br />
<p align="center">
  <h3 align="center">Simple python package</h3>
  <p align="center">
    <a href="https://github.com/Georges-Ngandeu/SimplePythonPackage"><strong>Explore the docs »</strong></a>
    <br />
    <a href="https://github.com/Georges-Ngandeu/SimplePythonPackage">View Demo</a>
    ·
    <a href="https://github.com/Georges-Ngandeu/SimplePythonPackage">Report Bug</a>
    ·
    <a href="https://github.com/Georges-Ngandeu/SimplePythonPackage">Request Feature</a>
  </p>
</p>

<!-- TABLE OF CONTENTS -->
<details open="open">
  <summary><h2 style="display: inline-block">Table of Contents</h2></summary>
  <ol>
    <li><a href="#getting">Getting started</a></li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
    <li><a href="#acknowledgements">Acknowledgements</a></li>
  </ol>
</details>


<!-- GETTING STARTED -->
## Getting Started
A simple python package that prints "Hello wolrd"
<!-- USAGE EXAMPLES -->
## Usage

<!-- LICENSE -->
## License

<!-- CONTACT -->
## Contact

Project Link: [https://github.com/Georges-Ngandeu/SimplePythonPackage](https://github.com/Georges-Ngandeu/SimplePythonPackage)

<!-- ACKNOWLEDGEMENTS -->
## Acknowledgements

* []()
* []()
* []()

<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[contributors-shield]: https://img.shields.io/github/contributors/github_username/repo.svg?style=for-the-badge
[contributors-url]: https://github.com/github_username/repo/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/github_username/repo.svg?style=for-the-badge
[forks-url]: https://github.com/github_username/repo/network/members
[stars-shield]: https://img.shields.io/github/stars/github_username/repo.svg?style=for-the-badge
[stars-url]: https://github.com/github_username/repo/stargazers
[issues-shield]: https://img.shields.io/github/issues/github_username/repo.svg?style=for-the-badge
[issues-url]: https://github.com/github_username/repo/issues
[license-shield]: https://img.shields.io/github/license/github_username/repo.svg?style=for-the-badge
[license-url]: https://github.com/github_username/repo/blob/master/LICENSE.txt
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555
[linkedin-url]: https://linkedin.com/in/github_username
